@@ -146,6 +146,7 @@ set_property (GObject *object, guint prop_id,
 		priv->proxy = g_value_get_boolean (value);
 		break;
 	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
 }
@@ -174,6 +175,7 @@ get_property (GObject *object, guint prop_id,
 		g_value_set_boolean (value, soup_auth_is_authenticated (auth));
 		break;
 	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
 }
@@ -210,7 +212,7 @@ soup_auth_new (GType type, SoupMessage *msg, const char *auth_header)
 			     NULL);
 
 	scheme = soup_auth_get_scheme_name (auth);
-	if (strncmp (auth_header, scheme, strlen (scheme)) != 0) {
+	if (g_ascii_strncasecmp (auth_header, scheme, strlen (scheme)) != 0) {
 		g_object_unref (auth);
 		return NULL;
 	}
@@ -300,7 +302,8 @@ soup_auth_authenticate (SoupAuth *auth, const char *username, const char *passwo
 	gboolean was_authenticated;
 
 	g_return_if_fail (SOUP_IS_AUTH (auth));
-	g_return_if_fail (username != NULL || password == NULL);
+	g_return_if_fail (username != NULL);
+	g_return_if_fail (password != NULL);
 
 	was_authenticated = soup_auth_is_authenticated (auth);
 	SOUP_AUTH_GET_CLASS (auth)->authenticate (auth, username, password);
